import { ref, computed } from 'vue'
import { defineStore } from 'pinia'
import { isString, isUndefined, toNumber } from 'lodash';
import z from "zod"
import { isNumber } from 'mathjs';

export const useEquipments = defineStore('equipments', () => {
  const boardAddr = ref("127.0.0.1")
  const boardPort = ref(1234)
  const jtagBitstream = ref<File>()

  function setAddr(address: string | undefined) {
    if (isUndefined(address)) return;
    if (z.string().ip("4").safeParse(address).success)
      boardAddr.value = address;
  }

  function setPort(port: string | number | undefined) {
    if (isUndefined(port)) return;

    if (isString(port) && port.length != 0) {
      const portNumber = toNumber(port);
      if (z.number().nonnegative().max(65535).safeParse(portNumber).success)
        boardPort.value = portNumber;
    }
    else if (isNumber(port)) {
      if (z.number().nonnegative().max(65535).safeParse(port).success)
        boardPort.value = port;
    }
  }

  return {
    boardAddr,
    boardPort,
    setAddr,
    setPort,
    jtagBitstream,
  }
})

